//
//  EditPackageTableViewController.swift
//  Vok
//
//  Created by Wilhelm Oks on 27.10.15.
//  Copyright © 2015 SIC! Software GmbH. All rights reserved.
//

import UIKit
import Foundation

class EditPackageTableViewController : UITableViewController {
    
    var package: Package!
    
    weak var currentTextField: UITextField?
    
    @IBOutlet weak var packageNameTextfield: UITextField!
    
    override func viewDidLoad() {
        super.viewDidLoad()
        
        packageNameTextfield.text = package.name
        packageNameTextfield.delegate = self
    }
    
    override func viewWillDisappear(animated: Bool) {
        super.viewWillDisappear(animated)
        currentTextField?.resignFirstResponder()
    }
    
    @IBAction func didTapAddButton(sender: AnyObject) {
        package.vocabulary += [Vocable(original: "", translation: "")]
        tableView.reloadData()
    }
    
    @IBAction func didTapActionButton(sender: UIBarButtonItem) {
        package.saveToFile()
        
        let packageItem = VokPackageActivityItemProvider(package: package)
        let activityViewController = UIActivityViewController(activityItems: [packageItem], applicationActivities: nil)
        activityViewController.modalPresentationStyle = .Popover
        presentViewController(activityViewController, animated: true, completion: nil)
        
        let popoverController = activityViewController.popoverPresentationController
        popoverController?.permittedArrowDirections = .Any
        popoverController?.barButtonItem = sender
    }
    
    override func tableView(tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        return package.vocabulary.count
    }
    
    override func tableView(tableView: UITableView, cellForRowAtIndexPath indexPath: NSIndexPath) -> UITableViewCell {
        let cell = tableView.dequeueReusableCellWithIdentifier("vocable", forIndexPath: indexPath) as! EditVocableTableViewCell
        
        cell.vocable = package.vocabulary[indexPath.row]
        cell.setup()
        
        return cell
    }
    
    override func tableView(tableView: UITableView, commitEditingStyle editingStyle: UITableViewCellEditingStyle, forRowAtIndexPath indexPath: NSIndexPath) {
        if editingStyle == .Delete {
            package.vocabulary.removeAtIndex(indexPath.row)
        }
        tableView.reloadData()
    }
    
}

extension EditPackageTableViewController : UITextFieldDelegate {
    func textFieldDidEndEditing(textField: UITextField) {
        if textField == packageNameTextfield {
            package.name = textField.text ?? ""
        }
    }
    
    func textFieldShouldReturn(textField: UITextField) -> Bool {
        textField.resignFirstResponder()
        return true
    }
    
    func textFieldDidBeginEditing(textField: UITextField) {
        currentTextField = textField
    }
}
