//
//  Package.swift
//  Vok
//
//  Created by Wilhelm Oks on 27.10.15.
//  Copyright © 2015 SIC! Software GmbH. All rights reserved.
//

import Foundation

class Package {
    var name: String
    var vocabulary: [Vocable]
    
    init(name: String, vocabulary: [Vocable]) {
        self.name = name
        self.vocabulary = vocabulary
    }
    
    convenience init(fromFileUrl fileUrl: NSURL) {
        let packageDictionary = NSKeyedUnarchiver.unarchiveObjectWithFile(fileUrl.path!) as? [String: AnyObject] ?? [:]
        self.init(fromDictionary: packageDictionary)
    }
    
    init(fromDictionary dictionary: [String: AnyObject]) {
        name = dictionary["name"] as? String ?? ""
        vocabulary = (dictionary["vocabulary"] as? [[String: String]] ?? []).map{ Vocable(original: $0["original"] ?? "", translation: $0["translation"] ?? "") }
    }
    
    func asDictionary() -> [String: AnyObject] {
        return ["name": name, "vocabulary": vocabulary.map{ ["original": $0.original, "translation": $0.translation] }]
    }
    
    func fileUrl() -> NSURL {
        let illegalFileNameCharacters = NSMutableCharacterSet(charactersInString: "/\\?%*|\"<>")
        illegalFileNameCharacters.formUnionWithCharacterSet(NSCharacterSet.illegalCharacterSet())
        illegalFileNameCharacters.formUnionWithCharacterSet(NSCharacterSet.whitespaceAndNewlineCharacterSet())
        illegalFileNameCharacters.formUnionWithCharacterSet(NSCharacterSet.symbolCharacterSet())
        
        var fileName = name.componentsSeparatedByCharactersInSet(illegalFileNameCharacters).joinWithSeparator("_")
        if fileName.isEmpty {
            fileName = "(unnamed)"
        }
        return NSURL(fileURLWithPath: Package.directoryPath).URLByAppendingPathComponent(fileName).URLByAppendingPathExtension(Package.fileExtension)
    }
    
    func saveToFile() {
        let packageDictionary = asDictionary()
        NSKeyedArchiver.archiveRootObject(packageDictionary, toFile: fileUrl().path!)
    }
    
    static var fileExtension: String {
        return "vok"
    }
    
    static var directoryPath: String {
        return NSSearchPathForDirectoriesInDomains(NSSearchPathDirectory.DocumentDirectory, NSSearchPathDomainMask.UserDomainMask, true).first!
    }
}
