//
//  PackagesTableViewController.swift
//  Vok
//
//  Created by Wilhelm Oks on 27.10.15.
//  Copyright © 2015 SIC! Software GmbH. All rights reserved.
//

import UIKit

class PackagesTableViewController: UITableViewController {
    
    var packages = [Package]()
    weak static var instance: PackagesTableViewController?

    override func viewDidLoad() {
        super.viewDidLoad()
        
        PackagesTableViewController.instance = self
        
        print("packages path:\n\(Package.directoryPath)")

        loadPackages()
    }
    
    override func viewWillAppear(animated: Bool) {
        super.viewWillAppear(animated)
        
        savePackages()
        tableView.reloadData()
    }
    
    func createDefaultPackages() {
        packages = [
            Package(name: "Farben", vocabulary: [
                Vocable(original: "rot", translation: "red"),
                Vocable(original: "grün", translation: "green"),
                Vocable(original: "gelb", translation: "yellow"),
                ]),
            Package(name: "Zahlen", vocabulary: [
                Vocable(original: "fünf", translation: "five"),
                Vocable(original: "zwölf", translation: "twelve"),
                ]),
        ]
        
        savePackages()
    }

    func loadPackages() {
        var packageFileNames = NSFileManager.defaultManager().subpathsAtPath(Package.directoryPath) ?? []
        packageFileNames = packageFileNames.filter { NSURL(fileURLWithPath: $0).pathExtension?.lowercaseString == Package.fileExtension }
        if packageFileNames.count > 0 {
            packages = []
            for fileName in packageFileNames {
                let fileUrl = NSURL(fileURLWithPath: Package.directoryPath).URLByAppendingPathComponent(fileName)
                packages += [Package(fromFileUrl: fileUrl)]
            }
        } else {
            createDefaultPackages()
        }
        tableView.reloadData()
    }
    
    func savePackages() {
        let packageFileNames = NSFileManager.defaultManager().subpathsAtPath(Package.directoryPath) ?? []
        for fileName in packageFileNames {
            let fileUrl = NSURL(fileURLWithPath: Package.directoryPath).URLByAppendingPathComponent(fileName)
            _ = try? NSFileManager.defaultManager().removeItemAtURL(fileUrl)
        }
        
        for package in packages {
            package.saveToFile()
        }
    }

    override func tableView(tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        return packages.count
    }
    
    @IBAction func didTapAddButton(sender: AnyObject) {
        packages += [Package(name: "", vocabulary: [])]
        savePackages()
        tableView.reloadData()
    }

    override func tableView(tableView: UITableView, cellForRowAtIndexPath indexPath: NSIndexPath) -> UITableViewCell {
        let cell = tableView.dequeueReusableCellWithIdentifier("package", forIndexPath: indexPath)
        cell.textLabel?.text = packages[indexPath.row].name
        return cell
    }
    
    override func tableView(tableView: UITableView, commitEditingStyle editingStyle: UITableViewCellEditingStyle, forRowAtIndexPath indexPath: NSIndexPath) {
        if editingStyle == .Delete {
            packages.removeAtIndex(indexPath.row)
        }
        savePackages()
        tableView.reloadData()
    }
    
    override func prepareForSegue(segue: UIStoryboardSegue, sender: AnyObject?) {
        let indexPath = tableView.indexPathForCell(sender as! UITableViewCell)!
        let package = packages[indexPath.row]
        
        if segue.identifier == "edit_package" {
            (segue.destinationViewController as! EditPackageTableViewController).package = package
        } else if segue.identifier == "show_package" {
            (segue.destinationViewController as! LearnViewController).package = package
        }
    }
}
